@@ -1,4 +1,4 @@
-/* $Id: acconfig.h,v 1.3 2000/11/27 13:38:26 qha Exp $ */
+/* $Id: acconfig.h,v 1.4 2002/09/03 22:45:53 qha Exp $ */
 
 /* Define if you have the /dev/random file */
 #undef HAVE__DEV_RANDOM
@@ -6,10 +6,10 @@
 /* Define if you have the /dev/urandom file */
 #undef HAVE__DEV_URANDOM
 
-/* Define if you want the /dev/random file */
+/* Define if you want bogosort to use the /dev/random file */
 #undef WANT__DEV_RANDOM
 
-/* Define if you want the /dev/urandom file */
+/* Define if you want bogosort to use the /dev/urandom file */
 #undef WANT__DEV_URANDOM
 
 /* Define if your C librairy defines 'extern char *sys_errlist[]' */
@@ -17,3 +17,9 @@
 
 /* Define if your C librairy defines 'extern const char *const sys_errlist[]' */
 #undef HAVE_GNU_STYLE_SYS_ERRLIST
+
+/* Define if you have the strerror function.  */
+#undef HAVE_STRERROR
+
+/* Define if you have the strerror_r function.  */
+#undef HAVE_STRERROR_R
