@@ -2,7 +2,7 @@
 /*
    bogosort - sorts or doesn't sort files or its standard input
 
-   Copyright (C) 2000, 2001, 2002 Ulrik Haugen
+   Copyright (C) 2000, 2001, 2002, 2003 Ulrik Haugen
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
 */
-/* $Id: bogosort.c,v 1.7 2002/08/29 22:19:51 qha Exp $ */
+/* $Id: bogosort.c,v 1.9 2003/06/30 21:59:13 qha Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -72,7 +72,6 @@ main(int argc, char **argv)
     int element;
     char *iname = NULL;		/* infiles */
     FILE *ifile = NULL;
-    char *temp = NULL;
     char **lines = NULL;
 
     /* The name the program was run with */
@@ -123,17 +122,23 @@ main(int argc, char **argv)
      */
     /* then randomize the lines until they're sorted */
     do {
-	for (sortedno = linecount - 1; sortedno > 0; sortedno--) {
-	    /* If you wonder why I don't just do
-	       element = rand() % (sortedno + 1);
-	       here - rand(3) on a Debian box should enlighten you */
-	    element = (int) ((rand() * (float) (sortedno + 1)) / (RAND_MAX + 1.0));
+        /* borrow the topmost element of lines (holding a NULL) to
+           make a hole */
+        for (sortedno = linecount; sortedno > 0; sortedno--) {
+            /* If you wonder why I don't just do
+               element = rand() % (sortedno);
+               here - rand(3) on a Debian box should enlighten you */
+            element = (int) ((rand() * (float) (sortedno)) / (RAND_MAX + 1.0));
 
-	    temp = lines[element];
-	    lines[element] = lines[sortedno];
-	    lines[sortedno] = temp;
-	}
-	if (verbose) fprintf(stderr, ".");
+            /* move the hole one line down */
+            lines[sortedno] = lines[element];
+            lines[element] = lines[sortedno - 1];
+        }
+        /* fill the hole (now at the bottom) */
+        lines[0] = lines[linecount];
+        /* replace the NULL at the end of the array */
+        lines[linecount] = NULL;
+        if (verbose) fprintf(stderr, ".");
     } while (!nosort && !sortedp(lines));
     if (verbose) fprintf(stderr, "\n");
 
@@ -294,7 +299,7 @@ decode_switches(int argc, char **argv)
 #endif
 		printf(_("\n"
 "Written by Ulrik Haugen\n\n"
-"Copyright (C) 2000, 2001, 2002 Ulrik Haugen\n"
+"Copyright (C) 2000, 2001, 2002, 2003 Ulrik Haugen\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n")
 		       );
