@@ -2,7 +2,7 @@
 
 #  bogosort - sorts or doesn't sort files or its standard input
 #
-#  Copyright (C) 2000 Ulrik Haugen
+#  Copyright (C) 2000, 2001, 2002 Ulrik Haugen
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ echo $result
 # simplify the test...
 cp $1 $result
 
-until ./bogotest $result ; do
+until ./zbogotest $result ; do
 	./bogosort --nosort --output $result $1
 done
 
